RequiredComponentsRegistrator

Struct RequiredComponentsRegistrator 

pub struct RequiredComponentsRegistrator<'a, 'w> { /* private fields */ }
This is a safe handle around ComponentsRegistrator and RequiredComponents to register required components.

Implementations

Source

impl<'a, 'w> RequiredComponentsRegistrator<'a, 'w>

pub fn components_registrator(&mut self) -> &mut ComponentsRegistrator<'w>

Provides access to the current World’s ComponentsRegistrator

pub fn register_required<C>(&mut self, constructor: impl Fn() -> C + 'static)
where C: Component,

Registers the Component C as an explicitly required component.

If the component was not already registered as an explicit required component then it is added as one, potentially overriding the constructor of an inherited required component, otherwise panics.

pub unsafe fn register_required_by_id<C>( &mut self, component_id: ComponentId, constructor: impl Fn() -> C + 'static, )
where C: Component,

Registers the Component with the given component_id ID as an explicitly required component.

If the component was not already registered as an explicit required component then it is added as one, potentially overriding the constructor of an inherited required component, otherwise panics.

Safety

component_id must be a valid ComponentId for C in the Components instance of self.

pub unsafe fn register_required_dynamic_with( &mut self, component_id: ComponentId, constructor: impl FnOnce() -> RequiredComponentConstructor, )

Registers the Component with the given component_id ID as an explicitly required component.

If the component was not already registered as an explicit required component then it is added as one, potentially overriding the constructor of an inherited required component, otherwise panics.

Safety
  • component_id must be valid in the Components instance of self;
  • constructor must return a RequiredComponentConstructor that constructs a valid instance for the component with ID component_id.